@@ -39,21 +39,21 @@ class BroadcastThread(Thread):
 
 class GSPeerConnectionBroadcasterPiCaller:
     def __init__(self, gsdbs, camera, oncommand=None, setChannel=None):
-        self.sio = socketio.AsyncClient()
+        self.sio = socketio.Client()
         self.gsdbs = gsdbs
         self.camera = camera
         self._logger = logging.getLogger(__name__)
         self.oncommand = oncommand
         self.setChannel = setChannel
 
-    async def startSocket(self):
+    def startSocket(self):
         self._logger.debug("start broadcast socket")
-        await GSPeerConnectionBroadcasterPiSocketv2.create(self.sio,
-                                                           self.gsdbs,
-                                                           self.camera,
-                                                           self.oncommand,
-                                                           self.setChannel
-                                                           )
+        GSPeerConnectionBroadcasterPiSocketv2.create(self.sio, self.gsdbs, self.camera, self.oncommand, self.setChannel)
+
+    def getconnectionurl(self):
+        connectURL = self.gsdbs.credentials["signalserver"]
+
+        return f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}'
 
 
 class GSPeerConnectionBroadcasterPiSocket:
@@ -407,6 +407,6 @@ class GSPeerConnectionBroadcasterPiSocketv2:
         else:
             connectURL = self.gsdbs.credentials["signalserver"]
 
-        await self.sio.connect(
+        self.sio.connect(
             f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}')
-        await self.sio.wait()
+        self.sio.wait()
