@@ -46,10 +46,11 @@ def force_codec(pc, sender, forced_codec):
 class GSPeerConnectionBroadcasterUniversal:
 
     @classmethod
-    async def create(cls, gsdbs):
+    async def create(cls, gsdbs, oncommand=None):
         self = GSPeerConnectionBroadcasterUniversal()
         self.rtconfiList = []
         self.gsdbs = gsdbs
+        self.oncommand = oncommand
         if self.gsdbs.credentials["stunenable"]:
             self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
         if self.gsdbs.credentials["turnenable"]:
